"""Constants for the whole project"""


MODELS = (
    'gpt-3.5-turbo',
    'gpt-3.5-turbo-0613',
    'gpt-4',
    'gpt-4-0613',
)
MODELS_EMBEDDING = (
    'text-embedding-ada-002',
)

MAX_TOKENS = (
    (MODELS[0], 4096),
    (MODELS[1], 4096),
    (MODELS[2], 4096),
    (MODELS[3], 4096)
)

ROLES = (  # roles for messages objects
    'system',
    'user',
    'assistant'
)  # see https://platform.openai.com/docs/guides/gpt/chat-completions-api

EMBEDDINGS_COLUMNS = ('chunks', 'n_tokens', 'embeddings')

DEBUG = False



"""
    Package aissistant

    This can be an sample app using the package
    or the app itself to feed the __main__ and gui
    modules.
"""

import logging
from logging.config import dictConfig

from genaikit import CONFIG_LOG

dictConfig(CONFIG_LOG)

class MyApp:
    def __init__(self, *args, **kwargs):
        pass



"""
    Package aissistant

    <Write the package's description here>
"""

import logging
from logging import NullHandler
from logging.config import dictConfig

from genaikit.settings import CONFIG_LOG

from . import core  # The core module is the packages's API
from . import base
from . import data
from . import utils
from . import constants

from .core import QuestionContext

dictConfig(CONFIG_LOG)

# Set default logging handler to avoid \"No handler found\" warnings.
logging.getLogger(__name__).addHandler(NullHandler())

__all__ = [
    'constants',
    'core',
    'base',
    'data',
    'utils',
]
